@@ -78,7 +78,7 @@ utils::globalVariables(c('nRootedShapes',
 RootedTreeShape <- function (tree) {
   edge <- tree$edge
   nTip <- NTip(tree)
-  edge <- Postorder(edge, renumber = FALSE)
+  edge <- Postorder(edge, renumber = FALSE, sizeSort = TRUE)
   .Int64(edge_to_rooted_shape(edge[, 1], edge[, 2], nTip))
 }
 
@@ -175,7 +175,7 @@ UnrootedTreeShape <- function (tree) {
 #' @export
 UnrootedTreeKey <- function (tree, asInteger = FALSE) {
   tree <- Preorder(tree) # Guarantee unique representation of tree
-  edge <- Postorder(tree$edge, renumber = FALSE)
+  edge <- Postorder(tree$edge, renumber = FALSE, sizeSort = TRUE)
   nTip <- NTip(tree)
   parent <- edge[, 1]
   child <- edge[, 2]
