@@ -1,5 +1,3 @@
-context("tree_properties.R")
-
 nasty <- structure(list(edge = structure(
   c(9, 12, 10, 13, 11, 10, 11, 13, 10, 13, 12, 9,
     5, 10,  1,  2,  3, 13,  9,  4, 11,  7,  8, 6),
@@ -51,14 +49,14 @@ test_that('Root node can be found', {
 })
 
 test_that('NodeOrder() works', {
-  expect_equivalent(c(2L, rep(3L, 6)),
-                    as.integer(NodeOrder(BalancedTree(8), internalOnly = TRUE)))
-  expect_equivalent(c(rep(1L, 8), 2L, rep(3L, 6)),
-                    as.integer(NodeOrder(BalancedTree(8), internalOnly = FALSE)))
-  expect_equivalent(rep(2L, 7), as.integer(NodeOrder(BalancedTree(8), FALSE)))
+  expect_equal(ignore_attr = TRUE, c(2L, rep(3L, 6)),
+               as.integer(NodeOrder(BalancedTree(8), internalOnly = TRUE)))
+  expect_equal(ignore_attr = TRUE, c(rep(1L, 8), 2L, rep(3L, 6)),
+               as.integer(NodeOrder(BalancedTree(8), internalOnly = FALSE)))
+  expect_equal(ignore_attr = TRUE, rep(2L, 7),
+               as.integer(NodeOrder(BalancedTree(8), FALSE)))
   tree <- CollapseNode(BalancedTree(8), 12:15)
-  expect_equivalent(c(`9` = 5L, `10` = 4L, `11` = 3L),
-                    as.integer(NodeOrder(tree$edge, internalOnly = TRUE)))
+  expect_equal(5:3, as.integer(NodeOrder(tree$edge, internalOnly = TRUE)))
   expect_equal(list(NodeOrder(tree), NodeOrder(tree)), NodeOrder(c(tree, tree)))
   expect_equal(NodeOrder(c(tree, tree)), NodeOrder(list(tree, tree)))
 
